==> nonebot_plugin_alconna-0.41.0-py3-none-any.whl: nonebot_plugin_alconna/uniseg/adapters/__init__.py <==
import os
import importlib
from pathlib import Path
from warnings import warn
from typing import Dict, cast

from nonebot import get_adapters

from ..loader import BaseLoader
from ..builder import MessageBuilder
from ..exporter import MessageExporter

root = Path(__file__).parent
loaders: Dict[str, BaseLoader] = {}
_adapters = [path.stem for path in root.iterdir() if path.is_dir() and not path.stem.startswith("_")]
for name in _adapters:
    try:
        module = importlib.import_module(f".{name}", __package__)
        loader = cast(BaseLoader, getattr(module, "Loader"))
        loaders[loader.get_adapter().value] = loader
    except Exception as e:
        warn(f"Failed to import uniseg adapter {name}: {e}", RuntimeWarning, 15)

EXPORTER_MAPPING: Dict[str, MessageExporter] = {}
BUILDER_MAPPING: Dict[str, MessageBuilder] = {}

try:
    adapters = get_adapters()
except Exception as e:
    warn(f"Failed to get nonebot adapters: {e}", RuntimeWarning, 15)
else:
    if not adapters:
        warn(
            "No adapters found, please make sure you have installed at least one adapter.",
            RuntimeWarning,
            15,
        )
    elif os.environ.get("PLUGIN_ALCONNA_TESTENV"):
        for adapter, loader in loaders.items():
            try:
                EXPORTER_MAPPING[adapter] = loaders[adapter].get_exporter()
                BUILDER_MAPPING[adapter] = loaders[adapter].get_builder()
            except Exception as e:
                warn(f"Failed to load uniseg adapter {adapter}: {e}", RuntimeWarning, 15)
    else:
        for adapter in adapters:
            if adapter in loaders:
                try:
                    EXPORTER_MAPPING[adapter] = loaders[adapter].get_exporter()
                    BUILDER_MAPPING[adapter] = loaders[adapter].get_builder()
                except Exception as e:
                    warn(f"Failed to load uniseg adapter {adapter}: {e}", RuntimeWarning, 15)
            else:
                warn(
                    f"Adapter {adapter} is not found in the uniseg.adapters,"
                    f"please go to the github repo and create an issue for it.",
                    RuntimeWarning,
                    15,
                )

==> nonebot_plugin_alconna-0.44.0-py3-none-any.whl: nonebot_plugin_alconna/uniseg/adapters/__init__.py <==
import os
import importlib
from pathlib import Path
from warnings import warn
from typing import Dict, cast
from contextlib import suppress

from nonebot import get_adapters

from ..loader import BaseLoader
from ..target import TargetFetcher
from ..builder import MessageBuilder
from ..exporter import MessageExporter

root = Path(__file__).parent
loaders: Dict[str, BaseLoader] = {}
_adapters = [path.stem for path in root.iterdir() if path.is_dir() and not path.stem.startswith("_")]
for name in _adapters:
    try:
        module = importlib.import_module(f".{name}", __package__)
        loader = cast(BaseLoader, getattr(module, "Loader")())
        loaders[loader.get_adapter().value] = loader
    except Exception as e:
        warn(f"Failed to import uniseg adapter {name}: {e}", RuntimeWarning, 15)

EXPORTER_MAPPING: Dict[str, MessageExporter] = {}
BUILDER_MAPPING: Dict[str, MessageBuilder] = {}
FETCHER_MAPPING: Dict[str, TargetFetcher] = {}

try:
    adapters = get_adapters()
except Exception as e:
    warn(f"Failed to get nonebot adapters: {e}", RuntimeWarning, 15)
else:
    if not adapters:
        warn(
            "No adapters found, please make sure you have installed at least one adapter.",
            RuntimeWarning,
            15,
        )
    elif os.environ.get("PLUGIN_ALCONNA_TESTENV"):
        for adapter, loader in loaders.items():
            try:
                EXPORTER_MAPPING[adapter] = loaders[adapter].get_exporter()
                BUILDER_MAPPING[adapter] = loaders[adapter].get_builder()
                with suppress(NotImplementedError):
                    FETCHER_MAPPING[adapter] = loaders[adapter].get_fetcher()
            except Exception as e:
                warn(f"Failed to load uniseg adapter {adapter}: {e}", RuntimeWarning, 15)
    else:
        for adapter in adapters:
            if adapter in loaders:
                try:
                    EXPORTER_MAPPING[adapter] = loaders[adapter].get_exporter()
                    BUILDER_MAPPING[adapter] = loaders[adapter].get_builder()
                    with suppress(NotImplementedError):
                        FETCHER_MAPPING[adapter] = loaders[adapter].get_fetcher()
                except Exception as e:
                    warn(f"Failed to load uniseg adapter {adapter}: {e}", RuntimeWarning, 15)
            else:
                warn(
                    f"Adapter {adapter} is not found in the uniseg.adapters,"
                    f"please go to the github repo and create an issue for it.",
                    RuntimeWarning,
                    15,
                )
